#
# PySNMP MIB module UDP-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/UDP-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:32:28 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, ObjectIdentifier, Integer, ) = mibBuilder.importSymbols("ASN1", "OctetString", "ObjectIdentifier", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsIntersection, ValueRangeConstraint, SingleValueConstraint, ValueSizeConstraint, ConstraintsUnion, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsIntersection", "ValueRangeConstraint", "SingleValueConstraint", "ValueSizeConstraint", "ConstraintsUnion")
( InetAddressType, InetAddress, InetPortNumber, ) = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetAddressType", "InetAddress", "InetPortNumber")
( ObjectGroup, NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "NotificationGroup", "ModuleCompliance")
( Unsigned32, Counter32, IpAddress, Gauge32, ObjectIdentity, NotificationType, MibIdentifier, Bits, ModuleIdentity, Integer32, iso, mib_2, MibScalar, MibTable, MibTableRow, MibTableColumn, TimeTicks, Counter64, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Unsigned32", "Counter32", "IpAddress", "Gauge32", "ObjectIdentity", "NotificationType", "MibIdentifier", "Bits", "ModuleIdentity", "Integer32", "iso", "mib-2", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "TimeTicks", "Counter64")
( DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
udpMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 50)).setRevisions(("2005-05-20 00:00", "1994-11-01 00:00", "1991-03-31 00:00",))
if mibBuilder.loadTexts: udpMIB.setLastUpdated('200505200000Z')
if mibBuilder.loadTexts: udpMIB.setOrganization('IETF IPv6 Working Group\n               http://www.ietf.org/html.charters/ipv6-charter.html')
if mibBuilder.loadTexts: udpMIB.setContactInfo('Bill Fenner (editor)\n\n               AT&T Labs -- Research\n               75 Willow Rd.\n               Menlo Park, CA 94025\n\n               Phone: +1 650 330-7893\n               Email: <fenner@research.att.com>\n\n               John Flick (editor)\n\n               Hewlett-Packard Company\n               8000 Foothills Blvd. M/S 5557\n               Roseville, CA 95747\n\n               Phone: +1 916 785 4018\n               Email: <john.flick@hp.com>\n\n               Send comments to <ipv6@ietf.org>')
if mibBuilder.loadTexts: udpMIB.setDescription('The MIB module for managing UDP implementations.\n               Copyright (C) The Internet Society (2005).  This\n               version of this MIB module is part of RFC 4113;\n               see the RFC itself for full legal notices.')
udp = MibIdentifier((1, 3, 6, 1, 2, 1, 7))
udpInDatagrams = MibScalar((1, 3, 6, 1, 2, 1, 7, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: udpInDatagrams.setDescription('The total number of UDP datagrams delivered to UDP\n               users.\n\n               Discontinuities in the value of this counter can occur\n               at re-initialization of the management system, and at\n               other times as indicated by discontinuities in the\n               value of sysUpTime.')
udpNoPorts = MibScalar((1, 3, 6, 1, 2, 1, 7, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: udpNoPorts.setDescription('The total number of received UDP datagrams for which\n               there was no application at the destination port.\n\n               Discontinuities in the value of this counter can occur\n               at re-initialization of the management system, and at\n               other times as indicated by discontinuities in the\n               value of sysUpTime.')
udpInErrors = MibScalar((1, 3, 6, 1, 2, 1, 7, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: udpInErrors.setDescription('The number of received UDP datagrams that could not be\n               delivered for reasons other than the lack of an\n               application at the destination port.\n\n               Discontinuities in the value of this counter can occur\n               at re-initialization of the management system, and at\n               other times as indicated by discontinuities in the\n               value of sysUpTime.')
udpOutDatagrams = MibScalar((1, 3, 6, 1, 2, 1, 7, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: udpOutDatagrams.setDescription('The total number of UDP datagrams sent from this\n               entity.\n\n               Discontinuities in the value of this counter can occur\n               at re-initialization of the management system, and at\n               other times as indicated by discontinuities in the\n               value of sysUpTime.')
udpHCInDatagrams = MibScalar((1, 3, 6, 1, 2, 1, 7, 8), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: udpHCInDatagrams.setDescription('The total number of UDP datagrams delivered to UDP\n               users, for devices that can receive more than 1\n               million UDP datagrams per second.\n\n               Discontinuities in the value of this counter can occur\n               at re-initialization of the management system, and at\n               other times as indicated by discontinuities in the\n               value of sysUpTime.')
udpHCOutDatagrams = MibScalar((1, 3, 6, 1, 2, 1, 7, 9), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: udpHCOutDatagrams.setDescription('The total number of UDP datagrams sent from this\n               entity, for devices that can transmit more than 1\n               million UDP datagrams per second.\n\n               Discontinuities in the value of this counter can occur\n               at re-initialization of the management system, and at\n               other times as indicated by discontinuities in the\n               value of sysUpTime.')
udpEndpointTable = MibTable((1, 3, 6, 1, 2, 1, 7, 7), )
if mibBuilder.loadTexts: udpEndpointTable.setDescription("A table containing information about this entity's UDP\n               endpoints on which a local application is currently\n               accepting or sending datagrams.\n\n               The address type in this table represents the address\n               type used for the communication, irrespective of the\n               higher-layer abstraction.  For example, an application\n               using IPv6 'sockets' to communicate via IPv4 between\n               ::ffff:10.0.0.1 and ::ffff:10.0.0.2 would use\n               InetAddressType ipv4(1).\n\n               Unlike the udpTable in RFC 2013, this table also allows\n               the representation of an application that completely\n               specifies both local and remote addresses and ports.  A\n               listening application is represented in three possible\n               ways:\n\n               1) An application that is willing to accept both IPv4\n                  and IPv6 datagrams is represented by a\n                  udpEndpointLocalAddressType of unknown(0) and a\n                  udpEndpointLocalAddress of ''h (a zero-length\n                  octet-string).\n\n               2) An application that is willing to accept only IPv4\n                  or only IPv6 datagrams is represented by a\n                  udpEndpointLocalAddressType of the appropriate\n                  address type and a udpEndpointLocalAddress of\n                  '0.0.0.0' or '::' respectively.\n\n               3) An application that is listening for datagrams only\n                  for a specific IP address but from any remote\n                  system is represented by a\n                  udpEndpointLocalAddressType of the appropriate\n                  address type, with udpEndpointLocalAddress\n                  specifying the local address.\n\n               In all cases where the remote is a wildcard, the\n               udpEndpointRemoteAddressType is unknown(0), the\n               udpEndpointRemoteAddress is ''h (a zero-length\n               octet-string), and the udpEndpointRemotePort is 0.\n\n               If the operating system is demultiplexing UDP packets\n               by remote address and port, or if the application has\n               'connected' the socket specifying a default remote\n               address and port, the udpEndpointRemote* values should\n               be used to reflect this.")
udpEndpointEntry = MibTableRow((1, 3, 6, 1, 2, 1, 7, 7, 1), ).setIndexNames((0, "UDP-MIB", "udpEndpointLocalAddressType"), (0, "UDP-MIB", "udpEndpointLocalAddress"), (0, "UDP-MIB", "udpEndpointLocalPort"), (0, "UDP-MIB", "udpEndpointRemoteAddressType"), (0, "UDP-MIB", "udpEndpointRemoteAddress"), (0, "UDP-MIB", "udpEndpointRemotePort"), (0, "UDP-MIB", "udpEndpointInstance"))
if mibBuilder.loadTexts: udpEndpointEntry.setDescription('Information about a particular current UDP endpoint.\n\n               Implementers need to be aware that if the total number\n               of elements (octets or sub-identifiers) in\n               udpEndpointLocalAddress and udpEndpointRemoteAddress\n               exceeds 111, then OIDs of column instances in this table\n               will have more than 128 sub-identifiers and cannot be\n               accessed using SNMPv1, SNMPv2c, or SNMPv3.')
udpEndpointLocalAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 7, 7, 1, 1), InetAddressType())
if mibBuilder.loadTexts: udpEndpointLocalAddressType.setDescription('The address type of udpEndpointLocalAddress.  Only\n               IPv4, IPv4z, IPv6, and IPv6z addresses are expected, or\n               unknown(0) if datagrams for all local IP addresses are\n               accepted.')
udpEndpointLocalAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 7, 7, 1, 2), InetAddress())
if mibBuilder.loadTexts: udpEndpointLocalAddress.setDescription("The local IP address for this UDP endpoint.\n\n               The value of this object can be represented in three\n               possible ways, depending on the characteristics of the\n               listening application:\n\n               1. For an application that is willing to accept both\n                  IPv4 and IPv6 datagrams, the value of this object\n                  must be ''h (a zero-length octet-string), with\n                  the value of the corresponding instance of the\n                  udpEndpointLocalAddressType object being unknown(0).\n\n               2. For an application that is willing to accept only IPv4\n                  or only IPv6 datagrams, the value of this object\n                  must be '0.0.0.0' or '::', respectively, while the\n                  corresponding instance of the\n                  udpEndpointLocalAddressType object represents the\n                  appropriate address type.\n\n               3. For an application that is listening for data\n                  destined only to a specific IP address, the value\n                  of this object is the specific IP address for which\n                  this node is receiving packets, with the\n                  corresponding instance of the\n                  udpEndpointLocalAddressType object representing the\n                  appropriate address type.\n\n               As this object is used in the index for the\n               udpEndpointTable, implementors of this table should be\n               careful not to create entries that would result in OIDs\n               with more than 128 subidentifiers; else the information\n               cannot be accessed using SNMPv1, SNMPv2c, or SNMPv3.")
udpEndpointLocalPort = MibTableColumn((1, 3, 6, 1, 2, 1, 7, 7, 1, 3), InetPortNumber())
if mibBuilder.loadTexts: udpEndpointLocalPort.setDescription('The local port number for this UDP endpoint.')
udpEndpointRemoteAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 7, 7, 1, 4), InetAddressType())
if mibBuilder.loadTexts: udpEndpointRemoteAddressType.setDescription('The address type of udpEndpointRemoteAddress.  Only\n               IPv4, IPv4z, IPv6, and IPv6z addresses are expected, or\n               unknown(0) if datagrams for all remote IP addresses are\n               accepted.  Also, note that some combinations of\n               udpEndpointLocalAdressType and\n               udpEndpointRemoteAddressType are not supported.  In\n               particular, if the value of this object is not\n               unknown(0), it is expected to always refer to the\n               same IP version as udpEndpointLocalAddressType.')
udpEndpointRemoteAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 7, 7, 1, 5), InetAddress())
if mibBuilder.loadTexts: udpEndpointRemoteAddress.setDescription("The remote IP address for this UDP endpoint.  If\n               datagrams from any remote system are to be accepted,\n               this value is ''h (a zero-length octet-string).\n               Otherwise, it has the type described by\n               udpEndpointRemoteAddressType and is the address of the\n               remote system from which datagrams are to be accepted\n               (or to which all datagrams will be sent).\n\n               As this object is used in the index for the\n               udpEndpointTable, implementors of this table should be\n               careful not to create entries that would result in OIDs\n               with more than 128 subidentifiers; else the information\n               cannot be accessed using SNMPv1, SNMPv2c, or SNMPv3.")
udpEndpointRemotePort = MibTableColumn((1, 3, 6, 1, 2, 1, 7, 7, 1, 6), InetPortNumber())
if mibBuilder.loadTexts: udpEndpointRemotePort.setDescription('The remote port number for this UDP endpoint.  If\n               datagrams from any remote system are to be accepted,\n               this value is zero.')
udpEndpointInstance = MibTableColumn((1, 3, 6, 1, 2, 1, 7, 7, 1, 7), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: udpEndpointInstance.setDescription("The instance of this tuple.  This object is used to\n               distinguish among multiple processes 'connected' to\n               the same UDP endpoint.  For example, on a system\n               implementing the BSD sockets interface, this would be\n               used to support the SO_REUSEADDR and SO_REUSEPORT\n               socket options.")
udpEndpointProcess = MibTableColumn((1, 3, 6, 1, 2, 1, 7, 7, 1, 8), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: udpEndpointProcess.setDescription("The system's process ID for the process associated with\n               this endpoint, or zero if there is no such process.\n               This value is expected to be the same as\n               HOST-RESOURCES-MIB::hrSWRunIndex or SYSAPPL-MIB::\n               sysApplElmtRunIndex for some row in the appropriate\n               tables.")
udpTable = MibTable((1, 3, 6, 1, 2, 1, 7, 5), )
if mibBuilder.loadTexts: udpTable.setDescription('A table containing IPv4-specific UDP listener\n               information.  It contains information about all local\n               IPv4 UDP end-points on which an application is\n               currently accepting datagrams.  This table has been\n               deprecated in favor of the version neutral\n               udpEndpointTable.')
udpEntry = MibTableRow((1, 3, 6, 1, 2, 1, 7, 5, 1), ).setIndexNames((0, "UDP-MIB", "udpLocalAddress"), (0, "UDP-MIB", "udpLocalPort"))
if mibBuilder.loadTexts: udpEntry.setDescription('Information about a particular current UDP listener.')
udpLocalAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 7, 5, 1, 1), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: udpLocalAddress.setDescription('The local IP address for this UDP listener.  In the\n               case of a UDP listener that is willing to accept\n               datagrams for any IP interface associated with the\n               node, the value 0.0.0.0 is used.')
udpLocalPort = MibTableColumn((1, 3, 6, 1, 2, 1, 7, 5, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: udpLocalPort.setDescription('The local port number for this UDP listener.')
udpMIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 50, 2))
udpMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 50, 2, 1))
udpMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 50, 2, 2))
udpMIBCompliance2 = ModuleCompliance((1, 3, 6, 1, 2, 1, 50, 2, 1, 2)).setObjects(*(("UDP-MIB", "udpBaseGroup"), ("UDP-MIB", "udpEndpointGroup"), ("UDP-MIB", "udpHCGroup"),))
if mibBuilder.loadTexts: udpMIBCompliance2.setDescription('The compliance statement for systems that implement\n               UDP.\n\n               There are a number of INDEX objects that cannot be\n               represented in the form of OBJECT clauses in SMIv2, but\n               for which we have the following compliance\n               requirements, expressed in OBJECT clause form in this\n               description clause:\n\n               -- OBJECT      udpEndpointLocalAddressType\n               -- SYNTAX      InetAddressType { unknown(0), ipv4(1),\n               --                               ipv6(2), ipv4z(3),\n               --                               ipv6z(4) }\n               -- DESCRIPTION\n               --     Support for dns(5) is not required.\n               -- OBJECT      udpEndpointLocalAddress\n               -- SYNTAX      InetAddress (SIZE(0|4|8|16|20))\n               -- DESCRIPTION\n               --     Support is only required for zero-length\n               --     octet-strings, and for scoped and unscoped\n               --     IPv4 and IPv6 addresses.\n               -- OBJECT      udpEndpointRemoteAddressType\n               -- SYNTAX      InetAddressType { unknown(0), ipv4(1),\n               --                               ipv6(2), ipv4z(3),\n               --                               ipv6z(4) }\n               -- DESCRIPTION\n               --     Support for dns(5) is not required.\n               -- OBJECT      udpEndpointRemoteAddress\n               -- SYNTAX      InetAddress (SIZE(0|4|8|16|20))\n               -- DESCRIPTION\n               --     Support is only required for zero-length\n               --     octet-strings, and for scoped and unscoped\n               --     IPv4 and IPv6 addresses.\n              ')
udpMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 50, 2, 1, 1)).setObjects(*(("UDP-MIB", "udpGroup"),))
if mibBuilder.loadTexts: udpMIBCompliance.setDescription('The compliance statement for IPv4-only systems that\n               implement UDP.  For IP version independence, this\n               compliance statement is deprecated in favor of\n               udpMIBCompliance2.  However, agents are still\n               encouraged to implement these objects in order to\n               interoperate with the deployed base of managers.')
udpGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 50, 2, 2, 1)).setObjects(*(("UDP-MIB", "udpInDatagrams"), ("UDP-MIB", "udpNoPorts"), ("UDP-MIB", "udpInErrors"), ("UDP-MIB", "udpOutDatagrams"), ("UDP-MIB", "udpLocalAddress"), ("UDP-MIB", "udpLocalPort"),))
if mibBuilder.loadTexts: udpGroup.setDescription('The deprecated group of objects providing for\n               management of UDP over IPv4.')
udpBaseGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 50, 2, 2, 2)).setObjects(*(("UDP-MIB", "udpInDatagrams"), ("UDP-MIB", "udpNoPorts"), ("UDP-MIB", "udpInErrors"), ("UDP-MIB", "udpOutDatagrams"),))
if mibBuilder.loadTexts: udpBaseGroup.setDescription('The group of objects providing for counters of UDP\n               statistics.')
udpHCGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 50, 2, 2, 3)).setObjects(*(("UDP-MIB", "udpHCInDatagrams"), ("UDP-MIB", "udpHCOutDatagrams"),))
if mibBuilder.loadTexts: udpHCGroup.setDescription('The group of objects providing for counters of high\n               speed UDP implementations.')
udpEndpointGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 50, 2, 2, 4)).setObjects(*(("UDP-MIB", "udpEndpointProcess"),))
if mibBuilder.loadTexts: udpEndpointGroup.setDescription("The group of objects providing for the IP version\n               independent management of UDP 'endpoints'.")
mibBuilder.exportSymbols("UDP-MIB", udpEndpointInstance=udpEndpointInstance, udpLocalAddress=udpLocalAddress, udpEndpointLocalPort=udpEndpointLocalPort, udpEndpointLocalAddressType=udpEndpointLocalAddressType, udpMIB=udpMIB, udpHCOutDatagrams=udpHCOutDatagrams, udpInErrors=udpInErrors, udpEndpointGroup=udpEndpointGroup, udpMIBCompliance2=udpMIBCompliance2, udp=udp, udpEndpointLocalAddress=udpEndpointLocalAddress, udpLocalPort=udpLocalPort, udpMIBCompliance=udpMIBCompliance, udpEndpointProcess=udpEndpointProcess, udpInDatagrams=udpInDatagrams, udpEndpointTable=udpEndpointTable, udpOutDatagrams=udpOutDatagrams, udpEndpointRemoteAddressType=udpEndpointRemoteAddressType, PYSNMP_MODULE_ID=udpMIB, udpNoPorts=udpNoPorts, udpEndpointRemotePort=udpEndpointRemotePort, udpMIBConformance=udpMIBConformance, udpMIBCompliances=udpMIBCompliances, udpGroup=udpGroup, udpMIBGroups=udpMIBGroups, udpTable=udpTable, udpHCGroup=udpHCGroup, udpEndpointEntry=udpEndpointEntry, udpEndpointRemoteAddress=udpEndpointRemoteAddress, udpHCInDatagrams=udpHCInDatagrams, udpEntry=udpEntry, udpBaseGroup=udpBaseGroup)



#
# PySNMP MIB module ADSL2-LINE-TC-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/ADSL2-LINE-TC-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:03:54 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, OctetString, Integer, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "OctetString", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ValueRangeConstraint, ValueSizeConstraint, ConstraintsIntersection, ConstraintsUnion, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ValueRangeConstraint", "ValueSizeConstraint", "ConstraintsIntersection", "ConstraintsUnion")
( NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance")
( Gauge32, transmission, TimeTicks, ObjectIdentity, ModuleIdentity, Bits, Counter32, IpAddress, MibIdentifier, Integer32, Counter64, Unsigned32, NotificationType, MibScalar, MibTable, MibTableRow, MibTableColumn, iso, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Gauge32", "transmission", "TimeTicks", "ObjectIdentity", "ModuleIdentity", "Bits", "Counter32", "IpAddress", "MibIdentifier", "Integer32", "Counter64", "Unsigned32", "NotificationType", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "iso")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
adsl2TCMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 238, 2)).setRevisions(("2006-10-04 00:00",))
if mibBuilder.loadTexts: adsl2TCMIB.setLastUpdated('200610040000Z')
if mibBuilder.loadTexts: adsl2TCMIB.setOrganization('ADSLMIB Working Group')
if mibBuilder.loadTexts: adsl2TCMIB.setContactInfo('WG-email:  adslmib@ietf.org\n   Info:      https://www1.ietf.org/mailman/listinfo/adslmib\n\n             Chair:     Mike Sneed\n                        Sand Channel Systems\n             Postal:    P.O. Box 37324\n                        Raleigh NC 27627-732\n             Email:     sneedmike@hotmail.com\n             Phone:     +1 206 600 7022\n\n             Co-Chair & Co-editor:\n                        Menachem Dodge\n                        ECI Telecom Ltd.\n             Postal:    30 Hasivim St.\n                        Petach Tikva 49517,\n                        Israel.\n             Email:     mbdodge@ieee.org\n             Phone:     +972 3 926 8421\n\n\n\n\n\n\n             Co-editor: Moti Morgenstern\n                        ECI Telecom Ltd.\n             Postal:    30 Hasivim St.\n                        Petach Tikva 49517,\n                        Israel.\n             Email:     moti.morgenstern@ecitele.com\n             Phone:     +972 3 926 6258\n\n             Co-editor: Scott Baillie\n                        NEC Australia\n             Postal:    649-655 Springvale Road,\n                        Mulgrave, Victoria 3170,\n                        Australia.\n             Email:     scott.baillie@nec.com.au\n             Phone:     +61 3 9264 3986\n\n             Co-editor: Umberto Bonollo\n                        NEC Australia\n             Postal:    649-655 Springvale Road,\n                        Mulgrave, Victoria 3170,\n                        Australia.\n             Email:     umberto.bonollo@nec.com.au\n             Phone:     +61 3 9264 3385\n            ')
if mibBuilder.loadTexts: adsl2TCMIB.setDescription('This MIB Module provides Textual Conventions to be\n         used by the ADSL2-LINE-MIB module for the purpose of\n         managing ADSL, ADSL2, and ADSL2+ lines.\n\n        Copyright (C) The Internet Society (2006).  This version of\n        this MIB module is part of RFC 4706: see the RFC itself for\n        full legal notices.')
class Adsl2Unit(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2,))
    namedValues = NamedValues(("atuc", 1), ("atur", 2),)

class Adsl2Direction(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2,))
    namedValues = NamedValues(("upstream", 1), ("downstream", 2),)

class Adsl2TransmissionModeType(Bits, TextualConvention):
    namedValues = NamedValues(("ansit1413", 0), ("etsi", 1), ("g9921PotsNonOverlapped", 2), ("g9921PotsOverlapped", 3), ("g9921IsdnNonOverlapped", 4), ("g9921isdnOverlapped", 5), ("g9921tcmIsdnNonOverlapped", 6), ("g9921tcmIsdnOverlapped", 7), ("g9922potsNonOverlapped", 8), ("g9922potsOverlapped", 9), ("g9922tcmIsdnNonOverlapped", 10), ("g9922tcmIsdnOverlapped", 11), ("g9921tcmIsdnSymmetric", 12), ("reserved1", 13), ("reserved2", 14), ("reserved3", 15), ("reserved4", 16), ("reserved5", 17), ("g9923PotsNonOverlapped", 18), ("g9923PotsOverlapped", 19), ("g9923IsdnNonOverlapped", 20), ("g9923isdnOverlapped", 21), ("reserved6", 22), ("reserved7", 23), ("g9924potsNonOverlapped", 24), ("g9924potsOverlapped", 25), ("reserved8", 26), ("reserved9", 27), ("g9923AnnexIAllDigNonOverlapped", 28), ("g9923AnnexIAllDigOverlapped", 29), ("g9923AnnexJAllDigNonOverlapped", 30), ("g9923AnnexJAllDigOverlapped", 31), ("g9924AnnexIAllDigNonOverlapped", 32), ("g9924AnnexIAllDigOverlapped", 33), ("g9923AnnexLMode1NonOverlapped", 34), ("g9923AnnexLMode2NonOverlapped", 35), ("g9923AnnexLMode3Overlapped", 36), ("g9923AnnexLMode4Overlapped", 37), ("g9923AnnexMPotsNonOverlapped", 38), ("g9923AnnexMPotsOverlapped", 39), ("g9925PotsNonOverlapped", 40), ("g9925PotsOverlapped", 41), ("g9925IsdnNonOverlapped", 42), ("g9925isdnOverlapped", 43), ("reserved10", 44), ("reserved11", 45), ("g9925AnnexIAllDigNonOverlapped", 46), ("g9925AnnexIAllDigOverlapped", 47), ("g9925AnnexJAllDigNonOverlapped", 48), ("g9925AnnexJAllDigOverlapped", 49), ("g9925AnnexMPotsNonOverlapped", 50), ("g9925AnnexMPotsOverlapped", 51), ("reserved12", 52), ("reserved13", 53), ("reserved14", 54), ("reserved15", 55),)

class Adsl2RaMode(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3,))
    namedValues = NamedValues(("manual", 1), ("raInit", 2), ("dynamicRa", 3),)

class Adsl2InitResult(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(0, 1, 2, 3, 4, 5,))
    namedValues = NamedValues(("noFail", 0), ("configError", 1), ("configNotFeasible", 2), ("commFail", 3), ("noPeerAtu", 4), ("otherCause", 5),)

class Adsl2OperationModes(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 8, 9, 10, 11, 14, 15, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 36, 37, 38, 39, 40, 41,))
    namedValues = NamedValues(("defMode", 1), ("adsl", 2), ("g9923PotsNonOverlapped", 8), ("g9923PotsOverlapped", 9), ("g9923IsdnNonOverlapped", 10), ("g9923isdnOverlapped", 11), ("g9924potsNonOverlapped", 14), ("g9924potsOverlapped", 15), ("g9923AnnexIAllDigNonOverlapped", 18), ("g9923AnnexIAllDigOverlapped", 19), ("g9923AnnexJAllDigNonOverlapped", 20), ("g9923AnnexJAllDigOverlapped", 21), ("g9924AnnexIAllDigNonOverlapped", 22), ("g9924AnnexIAllDigOverlapped", 23), ("g9923AnnexLMode1NonOverlapped", 24), ("g9923AnnexLMode2NonOverlapped", 25), ("g9923AnnexLMode3Overlapped", 26), ("g9923AnnexLMode4Overlapped", 27), ("g9923AnnexMPotsNonOverlapped", 28), ("g9923AnnexMPotsOverlapped", 29), ("g9925PotsNonOverlapped", 30), ("g9925PotsOverlapped", 31), ("g9925IsdnNonOverlapped", 32), ("g9925isdnOverlapped", 33), ("g9925AnnexIAllDigNonOverlapped", 36), ("g9925AnnexIAllDigOverlapped", 37), ("g9925AnnexJAllDigNonOverlapped", 38), ("g9925AnnexJAllDigOverlapped", 39), ("g9925AnnexMPotsNonOverlapped", 40), ("g9925AnnexMPotsOverlapped", 41),)

class Adsl2PowerMngState(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))
    namedValues = NamedValues(("l0", 1), ("l1", 2), ("l2", 3), ("l3", 4),)

class Adsl2ConfPmsForce(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(0, 2, 3,))
    namedValues = NamedValues(("l3toL0", 0), ("l0toL2", 2), ("l0orL2toL3", 3),)

class Adsl2LConfProfPmMode(Bits, TextualConvention):
    namedValues = NamedValues(("allowTransitionsToIdle", 0), ("allowTransitionsToLowPower", 1),)

class Adsl2LineLdsf(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(0, 1,))
    namedValues = NamedValues(("inhibit", 0), ("force", 1),)

class Adsl2LdsfResult(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11,))
    namedValues = NamedValues(("none", 1), ("success", 2), ("inProgress", 3), ("unsupported", 4), ("cannotRun", 5), ("aborted", 6), ("failed", 7), ("illegalMode", 8), ("adminUp", 9), ("tableFull", 10), ("noResources", 11),)

class Adsl2SymbolProtection(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,))
    namedValues = NamedValues(("noProtection", 1), ("halfSymbol", 2), ("singleSymbol", 3), ("twoSymbols", 4), ("threeSymbols", 5), ("fourSymbols", 6), ("fiveSymbols", 7), ("sixSymbols", 8), ("sevenSymbols", 9), ("eightSymbols", 10), ("nineSymbols", 11), ("tenSymbols", 12), ("elevenSymbols", 13), ("twelveSymbols", 14), ("thirteeSymbols", 15), ("fourteenSymbols", 16), ("fifteenSymbols", 17), ("sixteenSymbols", 18),)

class Adsl2MaxBer(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3,))
    namedValues = NamedValues(("eminus3", 1), ("eminus5", 2), ("eminus7", 3),)

class Adsl2ScMaskDs(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(0,64)

class Adsl2ScMaskUs(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(0,8)

class Adsl2RfiDs(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(0,64)

class Adsl2PsdMaskDs(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(0,96)

class Adsl2PsdMaskUs(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(0,12)

class Adsl2Tssi(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(0,96)

class Adsl2LastTransmittedState(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131,))
    namedValues = NamedValues(("atucG9941", 0), ("atucQuiet1", 1), ("atucComb1", 2), ("atucQuiet2", 3), ("atucComb2", 4), ("atucIcomb1", 5), ("atucLineprob", 6), ("atucQuiet3", 7), ("atucComb3", 8), ("atucIComb2", 9), ("atucMsgfmt", 10), ("atucMsgpcb", 11), ("atucQuiet4", 12), ("atucReverb1", 13), ("atucTref1", 14), ("atucReverb2", 15), ("atucEct", 16), ("atucReverb3", 17), ("atucTref2", 18), ("atucReverb4", 19), ("atucSegue1", 20), ("atucMsg1", 21), ("atucReverb5", 22), ("atucSegue2", 23), ("atucMedley", 24), ("atucExchmarker", 25), ("atucMsg2", 26), ("atucReverb6", 27), ("atucSegue3", 28), ("atucParams", 29), ("atucReverb7", 30), ("atucSegue4", 31), ("atucShowtime", 32), ("aturG9941", 100), ("aturQuiet1", 101), ("aturComb1", 102), ("aturQuiet2", 103), ("aturComb2", 104), ("aturIcomb1", 105), ("aturLineprob", 106), ("aturQuiet3", 107), ("aturComb3", 108), ("aturIcomb2", 109), ("aturMsgfmt", 110), ("aturMsgpcb", 111), ("aturReverb1", 112), ("aturQuiet4", 113), ("aturReverb2", 114), ("aturQuiet5", 115), ("aturReverb3", 116), ("aturEct", 117), ("aturReverb4", 118), ("aturSegue1", 119), ("aturReverb5", 120), ("aturSegue2", 121), ("aturMsg1", 122), ("aturMedley", 123), ("aturExchmarker", 124), ("aturMsg2", 125), ("aturReverb6", 126), ("aturSegue3", 127), ("aturParams", 128), ("aturReverb7", 129), ("aturSegue4", 130), ("aturShowtime", 131),)

class Adsl2LineStatus(Bits, TextualConvention):
    namedValues = NamedValues(("noDefect", 0), ("lossOfFrame", 1), ("lossOfSignal", 2), ("lossOfPower", 3), ("initFailure", 4),)

class Adsl2ChAtmStatus(Bits, TextualConvention):
    namedValues = NamedValues(("noDefect", 0), ("noCellDelineation", 1), ("lossOfCellDelineation", 2),)

class Adsl2ChPtmStatus(Bits, TextualConvention):
    namedValues = NamedValues(("noDefect", 0), ("outOfSync", 1),)

mibBuilder.exportSymbols("ADSL2-LINE-TC-MIB", Adsl2LineStatus=Adsl2LineStatus, Adsl2Tssi=Adsl2Tssi, Adsl2ScMaskUs=Adsl2ScMaskUs, PYSNMP_MODULE_ID=adsl2TCMIB, Adsl2Direction=Adsl2Direction, Adsl2ConfPmsForce=Adsl2ConfPmsForce, Adsl2OperationModes=Adsl2OperationModes, Adsl2ScMaskDs=Adsl2ScMaskDs, Adsl2ChAtmStatus=Adsl2ChAtmStatus, Adsl2ChPtmStatus=Adsl2ChPtmStatus, Adsl2PsdMaskDs=Adsl2PsdMaskDs, Adsl2Unit=Adsl2Unit, Adsl2MaxBer=Adsl2MaxBer, Adsl2PsdMaskUs=Adsl2PsdMaskUs, Adsl2LineLdsf=Adsl2LineLdsf, Adsl2RfiDs=Adsl2RfiDs, Adsl2LdsfResult=Adsl2LdsfResult, Adsl2SymbolProtection=Adsl2SymbolProtection, Adsl2InitResult=Adsl2InitResult, Adsl2LastTransmittedState=Adsl2LastTransmittedState, adsl2TCMIB=adsl2TCMIB, Adsl2PowerMngState=Adsl2PowerMngState, Adsl2RaMode=Adsl2RaMode, Adsl2LConfProfPmMode=Adsl2LConfProfPmMode, Adsl2TransmissionModeType=Adsl2TransmissionModeType)



#
# PySNMP MIB module ARC-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/ARC-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:06:06 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ResourceId, ) = mibBuilder.importSymbols("ALARM-MIB", "ResourceId")
( ObjectIdentifier, OctetString, Integer, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "OctetString", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsIntersection, ConstraintsUnion, ValueRangeConstraint, SingleValueConstraint, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsIntersection", "ConstraintsUnion", "ValueRangeConstraint", "SingleValueConstraint", "ValueSizeConstraint")
( NotificationGroup, ModuleCompliance, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance", "ObjectGroup")
( mib_2, ObjectIdentity, MibScalar, MibTable, MibTableRow, MibTableColumn, iso, Counter64, Bits, ModuleIdentity, Unsigned32, Counter32, TimeTicks, NotificationType, MibIdentifier, IpAddress, Gauge32, Integer32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "mib-2", "ObjectIdentity", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "iso", "Counter64", "Bits", "ModuleIdentity", "Unsigned32", "Counter32", "TimeTicks", "NotificationType", "MibIdentifier", "IpAddress", "Gauge32", "Integer32")
( StorageType, TextualConvention, DisplayString, RowStatus, ) = mibBuilder.importSymbols("SNMPv2-TC", "StorageType", "TextualConvention", "DisplayString", "RowStatus")
arcMibModule = ModuleIdentity((1, 3, 6, 1, 2, 1, 117)).setRevisions(("2004-09-09 00:00",))
if mibBuilder.loadTexts: arcMibModule.setLastUpdated('200409090000Z')
if mibBuilder.loadTexts: arcMibModule.setOrganization('IETF Distributed Management Working Group')
if mibBuilder.loadTexts: arcMibModule.setContactInfo('WG EMail:  disman@ietf.org\n              Subscribe: disman-request@ietf.org\n              http://www.ietf.org/html.charters/disman-charter.html\n\n        Chair:     Randy Presuhn\n                   E-mail: randy_presuhn@mindspring.com\n\n        Editor:    Hing-Kam Lam\n                   Lucent Technologies, 4C-616\n                   101 Crawfords Corner Road\n\n                   Holmdel, NJ 07733\n                   USA\n                   Tel: +1 732 949 8338\n                   E-mail: hklam@lucent.com')
if mibBuilder.loadTexts: arcMibModule.setDescription('The MIB module describes the objects for controlling a resource\n     in reporting alarm conditions that it detects.\n\n     Copyright (C) The Internet Society (2004).  This version\n     of this MIB module is part of RFC 3878;  see the RFC\n     itself for full legal notices.')
class IANAItuProbableCauseOrZero(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,2147483647)

arcTimeIntervals = MibIdentifier((1, 3, 6, 1, 2, 1, 117, 1))
arcObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 117, 2))
arcTITimeInterval = MibScalar((1, 3, 6, 1, 2, 1, 117, 1, 1), Unsigned32()).setUnits('seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: arcTITimeInterval.setDescription('This variable indicates the time interval used for the nalmTI\n     state, in units of second.  It is a pre-defined length of time\n     in which the resource will stay in the nalmTI state before\n     transition into the alm state.\n\n     Instances of this object SHOULD persist across agent restarts.')
arcCDTimeInterval = MibScalar((1, 3, 6, 1, 2, 1, 117, 1, 2), Unsigned32()).setUnits('seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: arcCDTimeInterval.setDescription('This variable indicates the time interval used for the nalmQICD\n     state, in units of second.  It is a pre-defined length of time\n     in which the resource will stay in the nalmQICD state before\n     transition into the alm state after it is problem-free.\n\n     Instances of this object SHOULD persist across agent restarts.')
arcTable = MibTable((1, 3, 6, 1, 2, 1, 117, 2, 1), )
if mibBuilder.loadTexts: arcTable.setDescription("A table of Alarm Reporting Control (ARC) settings on the system.\n\n     Alarm Reporting Control is a feature that provides an automatic\n     in-service provisioning capability.  Alarm reporting is turned\n     off on a per-resource basis for a selective set of potential\n     alarm conditions to allow sufficient time for customer testing\n     and other maintenance activities in an 'alarm free' state.\n     Once a resource is ready for service, alarm reporting is\n     automatically or manually turned on.\n\n     Functional description and requirements of Alarm Reporting\n     Control are defined in ITU-T Recommendation M.3100 Amendment 3\n     [M.3100 Amd3].")
arcEntry = MibTableRow((1, 3, 6, 1, 2, 1, 117, 2, 1, 1), ).setIndexNames((0, "ARC-MIB", "arcIndex"), (0, "ARC-MIB", "arcAlarmType"), (0, "ARC-MIB", "arcNotificationId"))
if mibBuilder.loadTexts: arcEntry.setDescription('A conceptual row that contains information about an ARC setting\n     of a resource in the system.\n\n     Implementation need to be aware that if the total size of\n     arcIndex and arcNotificationId exceeds 114 sub-IDs, then OIDs\n     of column instances in this table will have more than 128\n     sub-IDs and cannot be access using SNMPv1, SNMPv2c, or snmpv3.')
arcIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 117, 2, 1, 1, 1), ResourceId())
if mibBuilder.loadTexts: arcIndex.setDescription("This object uniquely identifies a resource, which is under the\n     arcState's control for the associated arcAlarmType.\n\n     For example, if the resource is an interface, this object will\n     point to an instance of interface, e.g., ifIndex.1.")
arcAlarmType = MibTableColumn((1, 3, 6, 1, 2, 1, 117, 2, 1, 1, 2), IANAItuProbableCauseOrZero())
if mibBuilder.loadTexts: arcAlarmType.setDescription('This object identifies the alarm condition type controlled by the\n     arcState.  It specifies the value 0 or a value of\n     IANAItuProbableCause that is applicable to the resource.\n     IANAItuProbableCause is defined in the IANA-ITU-ALARM-TC\n     module in the Alarm MIB document.\n\n\n     The value of zero (0) implies any probable causes that are\n     applicable to the resource.  Usually, the applicable probable\n     causes of a resource are specified in the resource-specific mib.')
arcNotificationId = MibTableColumn((1, 3, 6, 1, 2, 1, 117, 2, 1, 1, 3), ObjectIdentifier())
if mibBuilder.loadTexts: arcNotificationId.setDescription('This object identifies the type of notification to be suppressed.\n     The notification type identified should be the one normally used\n     by the resource for reporting its alarms.  When the value of 0.0 is\n     specified for this object, it implies all applicable notification\n     types.')
arcState = MibTableColumn((1, 3, 6, 1, 2, 1, 117, 2, 1, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("nalm", 1), ("nalmQI", 2), ("nalmTI", 3), ("nalmQICD", 4),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: arcState.setDescription("Defined in M.3100 Amendment 3 [M.3100 Amd3], there are five\n     ARC states: alm, nalm, nalmQI, nalmQICD, and nalmTI.\n\n        alm:        Alarm reporting is turned on (i.e., is allowed).\n        nalm:       Alarm reporting is turned off (i.e., not allowed).\n        nalmQI:     nalm - Qualified Inhibit. Alarm reporting is\n                    turned off until the managed entity is qualified\n                    problem-free for an optional persistence interval.\n                    Problem-free means that the condition corresponding\n                    to the specified alarm type is cleared.\n        nalmQICD:   nalmQI - Count down.  This is a substate of nalmQI\n                    and performs the persistence timing countdown\n                    function after the managed entity is qualified\n                    problem-free.\n        nalmTI:     nalm - Timed Inhibit.  Alarm reporting is turned\n                    off for a specified time interval.\n\n     alm may transition to nalm, nalmQI or nalmTI by management request.\n\n     nalm may transition to alm, nalmQI or nalmTI by management request.\n\n\n     nalmQI may transition to nalm or alm by management request.\n\n     nalmQI may transition to alm automatically\n             if qualified problem-free (if nalmQICD is not supported) or\n             if the CD timer expired (if nalmQICD is supported)\n\n     nalmTI may transition to alm or nalm by management request.\n\n     nalmTI may transition to alm automatically if the TI timer expired.\n\n     Further details of ARC state transitions are defined in Figure 3\n     of M.3100 Amd3 [M.3100 Amd3].\n\n     According to the requirements in M.3100 Amd3, a resource\n     supporting the ARC feature shall support the alm state and at\n     least one of the nalm, nalmTI, and nalmQI states. The nalmQICD\n     state is an optional substate of nalmQI.\n\n     The arcState object controls the alarm reporting state of a\n     resource. Note that the state alm (alarm reporting is allowed) is\n     not listed in the enumeration of the value of this object. However,\n     this state is implicitly supported by the mib.\n     Once a resource enters the normal reporting mode (i.e., in the alm\n     state) for the specified alarm type, the corresponding\n     row will be automatically deleted from the arc table.\n     Also the manual setting of arcState to alm can be achieved through\n     setting the RowStatus object to 'destroy'.\n\n     The nalamQICD state is a transitional state from nalmQI to alm. It\n     is optional depending on the resource type and the implementation\n     of the resource.  If it is supported, before the state\n     transitions from nalmQI to alm, a count down period is activated\n     for a duration set by the object arcNalmCDTimeInterval.  When the\n     time is up, the arcState transitions to alm.")
arcNalmTimeRemaining = MibTableColumn((1, 3, 6, 1, 2, 1, 117, 2, 1, 1, 5), Unsigned32()).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: arcNalmTimeRemaining.setDescription('This variable indicates the time remaining in the nalmTI state\n     or the nalmQICD state, in units of second.\n\n     At the moment the resource enters the nalmTI state, this variable\n     will have the initial value equal to the value of\n\n     arcNalmTITimeInterval and then starts decrementing as time goes by.\n\n     Similarly at the moment the resource enters the nalmQICD state,\n     this variable will have the initial value equal to the value of\n     arcNalmCDTimeInterval and then starts decrementing as time goes by.\n\n     This variable is read-create and thus will allow the manager to\n     write (extend or shorten), as needed, the remaining time when the\n     resource is in the nalmTI or nalmQICD state.\n\n     If this variable is supported and the resource is currently not in\n     the nalmTI nor nalmQICD state, the value of this variable shall\n     equal to zero.')
arcRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 117, 2, 1, 1, 6), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: arcRowStatus.setDescription('This columnar object is used for creating and deleting a conceptual\n     row of the arcTable.  It is used to create and delete an arc\n     setting.\n\n     Setting RowStatus to createAndGo or createAndWait implies creating\n     a new ARC setting for the specified resource and alarm type.\n     Setting RowStatus to destroy implies removing the ARC setting and\n     thus has the effect of resuming normal reporting behaviour of the\n     resource for the alarm type.\n\n     Only the objects arcState, arcNalmTimeRemaining, and arcRowStatus\n     can be updated when a row is active. All the objects, except\n     arcNalmTimeRemaining, must be set before the row can be activated.')
arcStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 117, 2, 1, 1, 7), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: arcStorageType.setDescription("The storage type for this conceptual row.\n     Conceptual rows having the value 'permanent' must\n     allow write-access at a minimum to arcState.\n     Note that arcState must allow change by management request.\n     Therefore, no row can be created with 'readOnly'.\n     If a set operation tries to set the value to 'readOnly',\n     then an 'inconsistentValue' error must be returned.")
arcConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 117, 3))
arcCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 117, 3, 1))
arcCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 117, 3, 1, 1)).setObjects(*(("ARC-MIB", "arcSettingGroup"),))
if mibBuilder.loadTexts: arcCompliance.setDescription('The compliance statement for systems supporting\n       the ARC MIB module.')
arcGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 117, 3, 2))
arcSettingGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 117, 3, 2, 1)).setObjects(*(("ARC-MIB", "arcState"), ("ARC-MIB", "arcRowStatus"), ("ARC-MIB", "arcStorageType"),))
if mibBuilder.loadTexts: arcSettingGroup.setDescription('A collection of objects applicable to\n      basic ARC setting.')
arcTIGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 117, 3, 2, 2)).setObjects(*(("ARC-MIB", "arcTITimeInterval"), ("ARC-MIB", "arcNalmTimeRemaining"),))
if mibBuilder.loadTexts: arcTIGroup.setDescription('A collection of objects applicable to\n      ARC setting that support the Time Inhibit (TI)\n      function.')
arcQICDGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 117, 3, 2, 3)).setObjects(*(("ARC-MIB", "arcCDTimeInterval"), ("ARC-MIB", "arcNalmTimeRemaining"),))
if mibBuilder.loadTexts: arcQICDGroup.setDescription('A collection of objects applicable to\n     ARC setting that support the Quality Inhibit (QI)\n     Count Down (CD) function.')
mibBuilder.exportSymbols("ARC-MIB", arcGroups=arcGroups, arcSettingGroup=arcSettingGroup, arcNotificationId=arcNotificationId, arcNalmTimeRemaining=arcNalmTimeRemaining, arcState=arcState, arcAlarmType=arcAlarmType, arcTimeIntervals=arcTimeIntervals, arcConformance=arcConformance, arcTable=arcTable, arcTIGroup=arcTIGroup, arcCDTimeInterval=arcCDTimeInterval, IANAItuProbableCauseOrZero=IANAItuProbableCauseOrZero, arcRowStatus=arcRowStatus, arcCompliances=arcCompliances, arcQICDGroup=arcQICDGroup, arcStorageType=arcStorageType, PYSNMP_MODULE_ID=arcMibModule, arcObjects=arcObjects, arcCompliance=arcCompliance, arcIndex=arcIndex, arcTITimeInterval=arcTITimeInterval, arcMibModule=arcMibModule, arcEntry=arcEntry)
